;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dracula-theme" "1.8.3"
  "Dracula Theme."
  '((emacs "24.3"))
  :url "https://github.com/dracula/emacs"
  :commit "ad30f50e06c1b4c3e461c647e976cd00b9bc4869"
  :revdesc "v1.8.3-0-gad30f50e06c1"
  :maintainers '(("tienne Deparis" . "etienne@depar.is")))
